@@ -1,6 +1,6 @@
 #!/bin/bash
 #		GMT EXAMPLE 18
-#		$Id: job18.sh 9606 2011-10-19 17:52:57Z pwessel $
+#		$Id: job18.sh 10180 2014-01-10 22:51:02Z pwessel $
 #
 # Purpose:	Illustrates volumes of grids inside contours and spatial
 #		selection of data
@@ -57,7 +57,7 @@ psxy -R -J -O -K -ST0.1i -Gyellow -Wthinnest pratt.d >> $ps
 # by masking out data outside the 200 km-radius circle
 # and then evaluate area/volume for the 50 mGal contour
 
-grdmath -R `cat pratt.d` GDIST = mask.nc
+grdmath -R `$AWK '{print $1, $2}' pratt.d` SDIST = mask.nc
 grdclip mask.nc -Sa200/NaN -Sb200/1 -Gmask.nc
 grdmath AK_gulf_grav.nc mask.nc MUL = tmp.nc
 area=`grdvolume tmp.nc -C50 -Sk | cut -f2`
@@ -65,8 +65,8 @@ volume=`grdvolume tmp.nc -C50 -Sk | cut -f3`
 
 psxy -R -J -A -O -K -L -Wthin -Gwhite >> $ps << END
 -148.5	52.75
--140.5	52.75
--140.5	53.75
+-141	52.75
+-141	53.75
 -148.5	53.75
 END
 pstext -R -J -O >> $ps << END
