@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: gmt_grdio.c 10007 2013-04-07 21:35:43Z pwessel $
+ *	$Id: gmt_grdio.c 10188 2014-01-26 22:55:38Z pwessel $
  *
- *	Copyright (c) 1991-2013 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2014 by P. Wessel and W. H. F. Smith
  *	See LICENSE.TXT file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -741,8 +741,8 @@ void GMT_grd_init (struct GRD_HEADER *header, int argc, char **argv, GMT_LONG up
 		strcpy (header->command, argv[0]);
 		len = strlen (header->command);
 		for (i = 1; len < GRD_COMMAND_LEN && i < argc; i++) {
-			len += strlen (argv[i]) + 1;
-			if (len > GRD_COMMAND_LEN) continue;
+			len += strlen (argv[i]) + 1;	/* Space plus arg */
+			if (len >= GRD_COMMAND_LEN) continue;
 			strcat (header->command, " ");
 			strcat (header->command, argv[i]);
 		}
