@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: gmt_notunix.h 9923 2012-12-18 20:45:53Z pwessel $
+ *	$Id: gmt_notunix.h 10211 2014-02-17 22:30:35Z fwobbe $
  *
- *	Copyright (c) 1991-2013 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2014 by P. Wessel and W. H. F. Smith
  *	See LICENSE.TXT file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -42,10 +42,9 @@
 #define _GMT_NOTUNIX_H
 
 /* A few general comments:
- * FLOCK is a pain. If cannot be used under EMX and _WIN32.
- * Also, users have problems with file locking because their 
- * NFS does not support it. Only those who are really sure should
- * activate -DFLOCK.
+ * FLOCK is buggy on UNIX and it cannot be used under WIN32.
+ * Some ancient NFS clients do not support it. However, it
+ * should be safe to activate -DFLOCK.
  */
 
 
@@ -251,7 +250,7 @@ EXTERN_MSC void DOS_path_fix (char *dir);
 
 #include <io.h>
 
-#undef FLOCK		/* Do not support file locking */
+#undef FLOCK		/* Do not enable file locking */
 #define SET_IO_MODE	/* Need to force binary i/o upon request */
 #define NO_FCNTL	/* fcntl.h does not exist here */
 #define GMT_STAT _stat
@@ -271,7 +270,7 @@ EXTERN_MSC void GMT_setmode (int i_or_o);
  
 #ifdef _WIN32	/* Start of NON-UNIX */
 
-#undef FLOCK		/* Do not support file locking */
+#undef FLOCK		/* Do not enable file locking */
 #define SET_IO_MODE	/* Need to force binary i/o upon request */
 
 EXTERN_MSC void GMT_setmode (int i_or_o);
