@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: gmt_support.h 9923 2012-12-18 20:45:53Z pwessel $
+ *	$Id: gmt_support.h 10173 2014-01-01 09:52:34Z pwessel $
  *
- *	Copyright (c) 1991-2013 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2014 by P. Wessel and W. H. F. Smith
  *	See LICENSE.TXT file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -21,6 +21,8 @@
 
 EXTERN_MSC GMT_LONG GMT_err_pass (GMT_LONG err, char *file);
 EXTERN_MSC void GMT_err_fail (GMT_LONG err, char *file);
+EXTERN_MSC void GMT_flip_angle_d (double *angle);
+EXTERN_MSC void GMT_flip_angle_f (float *angle);
 EXTERN_MSC GMT_LONG GMT_parse_multisegment_header (char *header, GMT_LONG use_cpt, GMT_LONG *use_fill, struct GMT_FILL *fill, struct GMT_FILL *def_fill,  GMT_LONG *use_pen, struct GMT_PEN *pen, struct GMT_PEN *def_pen, GMT_LONG def_outline);
 EXTERN_MSC GMT_LONG GMT_polygon_is_open (double x[], double y[], GMT_LONG n);
 EXTERN_MSC double GMT_cartesian_dist (double x0, double y0, double x1, double y1);
