@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: grdlandmask.c 10022 2013-04-20 04:15:51Z pwessel $
+ *	$Id: grdlandmask.c 10173 2014-01-01 09:52:34Z pwessel $
  *
- *	Copyright (c) 1991-2013 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2014 by P. Wessel and W. H. F. Smith
  *	See LICENSE.TXT file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -350,7 +350,6 @@ int main (int argc, char **argv)
 		}
 
 		if (!used_polygons) {	/* Lack of polygons or clipping etc resulted in no polygons after all, must deal with background */
-
 			k = INT_MAX;	/* Initialize to outside range of levels (4 is highest) */
 			/* Visit each of the 4 nodes, test if it is inside -R, and if so update lowest level found so far */
 
@@ -367,12 +366,22 @@ int main (int argc, char **argv)
 
 			j_min = (GMT_LONG)MAX (0, ceil ((header.y_max - c.lat_sw - c.bsize) * i_dy - del_off));
 			j_max = (GMT_LONG)MIN (ny1, floor ((header.y_max - c.lat_sw) * i_dy - del_off));
-			i_min = (GMT_LONG)ceil (fmod (c.lon_sw - header.x_min, 360.0) * i_dx - del_off);
-			i_max = (GMT_LONG)floor (fmod (c.lon_sw + c.bsize - header.x_min, 360.0) * i_dx - del_off);
 			if (wrap) {
+				i_min = (GMT_LONG)ceil (fmod (c.lon_sw - header.x_min, 360.0) * i_dx - del_off);
+				i_max = (GMT_LONG)floor (fmod (c.lon_sw + c.bsize - header.x_min, 360.0) * i_dx - del_off);
 				if (i_max < i_min) i_max += header.nx;
 			}
 			else {	/* Make sure we are inside our grid */
+				double lon_w, lon_e;
+				lon_w = c.lon_sw - header.x_min;	lon_e = c.lon_sw + c.bsize - header.x_min;
+				if (lon_w < header.x_min && (lon_w+360.0) < header.x_max) {
+					lon_w += 360.0;	lon_e += 360.0;
+				}
+				else if (lon_e > header.x_max && (lon_e-360.0) > header.x_min) {
+					lon_w -= 360.0;	lon_e -= 360.0;
+				}
+				i_min = (GMT_LONG)ceil (lon_w * i_dx - del_off);
+				i_max = (GMT_LONG)floor (lon_e * i_dx - del_off);
 				if (i_min < 0) i_min = 0;
 				if (i_max > nx1) i_max = nx1;
 			}
