@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: grdmask.c 9977 2013-01-12 20:08:07Z pwessel $
+ *	$Id: grdmask.c 10173 2014-01-01 09:52:34Z pwessel $
  *
- *	Copyright (c) 1991-2013 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2014 by P. Wessel and W. H. F. Smith
  *	See LICENSE.TXT file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -74,7 +74,7 @@ int main (int argc, char **argv)
 
 	char line[BUFSIZ], ptr[BUFSIZ];
 
-	GMT_LONG	i, j, side, fno, n_files = 0, n_args;
+	GMT_LONG	i, j, side = 0, fno, n_files = 0, n_args;
 	GMT_LONG	di, dj, i0, j0, n_fields, n_expected_fields, pos;
 	GMT_LONG 	distance_flag = 0, n_pol = 0;
 	GMT_LONG	k, ij, nm, n_path, n_read, n_alloc = GMT_CHUNK;
