@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: grdvector.c 9991 2013-03-22 03:53:34Z pwessel $
+ *	$Id: grdvector.c 10216 2014-02-27 19:24:21Z pwessel $
  *
- *	Copyright (c) 1991-2013 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2014 by P. Wessel and W. H. F. Smith
  *	See LICENSE.TXT file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -388,15 +388,7 @@ int main (int argc, char **argv)
         if (!Ctrl->N.active) GMT_map_clip_on (GMT_no_rgb, 3);
 
 	if (Ctrl->I.xinc != 0.0 && Ctrl->I.yinc != 0.0) {	/* Gave a coarser grid spacing, we hope */
-		struct GRD_HEADER tmp_h;
-		double val;
-		tmp_h = h[0];
-		tmp_h.x_inc = Ctrl->I.xinc;
-		tmp_h.y_inc = Ctrl->I.yinc;
-		GMT_RI_prepare (&tmp_h);	/* Convert to make sure we have correct increments */
-		Ctrl->I.xinc = tmp_h.x_inc;
-		Ctrl->I.yinc = tmp_h.y_inc;
-		val = Ctrl->I.yinc / h[0].y_inc;
+		double val = Ctrl->I.yinc / h[0].y_inc;
 		dj = irint (val);
 		if (dj == 0 || fabs (val - dj) > GMT_CONV_LIMIT) {
 			fprintf (stderr, "%s: Error: New y grid increment (%g) is not a multiple of actual grid increment (%g).\n", GMT_program, Ctrl->I.xinc, h[0].x_inc);
@@ -408,6 +400,7 @@ int main (int argc, char **argv)
 			fprintf (stderr, "%s: Error: New x grid increment (%g) is not a multiple of actual grid increment (%g).\n", GMT_program, Ctrl->I.xinc, h[0].x_inc);
 			exit (EXIT_FAILURE);
 		}
+		/* Determine starting point for straddled access */
 		tmp = ceil (h[0].y_max / Ctrl->I.yinc) * Ctrl->I.yinc;
 		if (tmp > h[0].y_max) tmp -= Ctrl->I.yinc;
 		j0 = irint ((h[0].y_max - tmp) / h[0].y_inc);
@@ -459,6 +452,17 @@ int main (int argc, char **argv)
 			else
 				r[ij] *= (float)Ctrl->S.factor;
 
+			if (project_info.projection == GMT_LINEAR) {	/* Must check if negative scales were used */
+				if (!project_info.xyz_pos[0]) {	/* Negative x scale */
+					if (!project_info.xyz_pos[1])	/* Negative y-scale too */
+						theta[ij] += 180.0f;
+					else
+						theta[ij] = 180.0f - theta[ij];
+				}
+				else if (!project_info.xyz_pos[1])	/* Negative y-scale only */
+					theta[ij] = - theta[ij];
+			}
+			GMT_flip_angle_f (&theta[ij]);
 			sincos (theta[ij], &s, &c);
 			x2 = plot_x + r[ij] * c;
 			y2 = plot_y + r[ij] * s;
