@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *    $Id: pscoupe.c 9923 2012-12-18 20:45:53Z pwessel $
+ *    $Id: pscoupe.c 10201 2014-02-07 19:07:39Z pwessel $
  *
- *    Copyright (c) 1996-2013 by G. Patau
+ *    Copyright (c) 1996-2014 by G. Patau
  *    Distributed under the GNU Public Licence
  *    See README file for copying and redistribution conditions.
  *--------------------------------------------------------------------*/
@@ -46,8 +46,8 @@ int main (int argc, char **argv)
     GMT_LONG     n_rec = 0;
 
     GMT_LONG    outline = FALSE, p_outline = FALSE, t_outline = FALSE;
-    GMT_LONG    error = FALSE, nofile = TRUE, polygon = FALSE;
-    GMT_LONG    done, get_rgb = FALSE, no_size_needed, greenwich;
+    GMT_LONG    error = FALSE, nofile = TRUE;
+    GMT_LONG    done, get_rgb = FALSE, no_size_needed;
     GMT_LONG    read_size = FALSE, read_proj = FALSE;
     GMT_LONG    read_cmt = FALSE, read_aki = FALSE, read_planes = FALSE;
     GMT_LONG    read_tensor = FALSE, read_axis = FALSE, read_point = FALSE;
@@ -55,7 +55,7 @@ int main (int argc, char **argv)
     GMT_LONG    plot_zerotrace = FALSE, tr_zerotrace = FALSE;
     GMT_LONG    transparence = FALSE, one_size = FALSE, no_label = FALSE;
     GMT_LONG    frame_coupe = FALSE;
-    GMT_LONG    old_GMT_world_map, skip_if_outside = TRUE;
+    GMT_LONG    skip_if_outside = TRUE;
     GMT_LONG    transparence_old = FALSE, not_defined = FALSE;
     
     double xy[2], west = 0.0, east = 0.0, south = 0.0, north = 0.0;
@@ -182,21 +182,18 @@ int main (int argc, char **argv)
                         xlonref = lon1;
                         ylatref = lat1;
                     }
-                    polygon = TRUE;
                     break;
                 case 'E':    /* Set color for extensive parts  */
                     if (!argv[i][2] || (argv[i][2] && GMT_getfill (&argv[i][2], &efill))) {
                         GMT_fill_syntax ('G', " ");
                         error++;
                     }
-                    polygon = TRUE;
                     break;
                 case 'G':    /* Set color for compressive parts */
                     if (!argv[i][2] || (argv[i][2] && GMT_getfill (&argv[i][2], &fill))) {
                         GMT_fill_syntax ('G', " ");
                         error++;
                     }
-                    polygon = TRUE;
                     break;
                 case 'L':    /* Draw outline [set outline attributes] */
                     outline = TRUE;
@@ -434,7 +431,6 @@ int main (int argc, char **argv)
                         GMT_fill_syntax ('e', " ");
                         error++;
                     }
-                    polygon = TRUE;
                     break;
                 case 'g':    /* Set color for P axis symbol */
                     if (!argv[i][2] || (argv[i][2] && GMT_getfill (&argv[i][2], &pfill))) {
@@ -442,7 +438,6 @@ int main (int argc, char **argv)
                         error++;
                     }
                     GMT_getfill (&argv[i][2], &pfill);
-                    polygon = TRUE;
                     break;
                 case 'p':    /* Draw outline of P axis symbol [set outline attributes] */
                     p_outline = TRUE;
@@ -603,8 +598,6 @@ int main (int argc, char **argv)
         if (GMT_IS_ZERO (PREF.dip)) PREF.dip = 1.0;
     }
 
-    greenwich = (project_info.w < 0.0 || project_info.e <= 0.0);
-    
     GMT_err_fail (GMT_map_setup (west, east, south, north), "");
 
     GMT_plotinit (argc, argv);
@@ -613,9 +606,7 @@ int main (int argc, char **argv)
     ps_setfont (gmtdefs.annot_font[0]);
     
     if (skip_if_outside) GMT_map_clip_on (GMT_no_rgb, 3);
-    
-    old_GMT_world_map = GMT_world_map;
-    
+        
     ix = (gmtdefs.xy_toggle[0]);    iy = 1 - ix;
 
     done = FALSE;
