@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: gmt2kml.c 10004 2013-04-04 21:14:48Z pwessel $
+ *	$Id: gmt2kml.c 10216 2014-02-27 19:24:21Z pwessel $
  *
- *	Copyright (c) 2009-2013 by P. Wessel
+ *	Copyright (c) 2009-2014 by P. Wessel
  *	See LICENSE.TXT file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -26,6 +26,11 @@
  
 #include "gmt.h"
 
+#ifdef WIN32    /* Special for Windows */
+#       include <process.h>
+#       define getpid _getpid
+#endif
+
 #define POINT	0
 #define EVENT	1
 #define SPAN	2
@@ -53,7 +58,7 @@ int main (int argc, char **argv)
 {
 	GMT_LONG i, j, k, fno, n_files = 0, n_args, fmode = POINT, altmode = KML_GROUND, n_coord = 0, itransp[5];
 	GMT_LONG ix, iy, t1_col, t2_col, pos, t_itransp, n_ext_cols = 0, n_alloc = 0, n_rec = 0;
-	GMT_LONG lod_min = 0, lod_max = 0, set_nr = 0, pnt_nr = 0, index = -4;
+	GMT_LONG lod_min = 0, lod_max = 0, set_nr = 0, pnt_nr = 0, index = -4, pid;
 
 	GMT_LONG error = FALSE, long_verbose = FALSE, nofile = TRUE, done = FALSE, greenwich = FALSE, first = TRUE;
 	GMT_LONG get_label = FALSE, no_label = FALSE, visible = TRUE, open = FALSE, use_folder = FALSE, format_label = FALSE;
@@ -486,7 +491,9 @@ int main (int argc, char **argv)
 	}
 	if (pen.width < 1.0) pen.width = 1.0;	/* Ensure we specify integer pen width */
 	
-	printf ("\t<Style id=\"GMT-4\">\n");
+	pid = getpid();
+	
+	printf ("\t<Style id=\"GMT-%ld-0\">\n", pid);	/* The default style */
 
 	/* Set icon style (applies to symbols only */
 	printf ("\t\t<IconStyle>\n\t\t\t<scale>%g</scale>\n\t\t\t<color>%2.2x%2.2x%2.2x%2.2x</color>\n\t\t\t<Icon>\n\t\t\t\t<href>%s</href>\n\t\t\t</Icon>\n\t\t</IconStyle>\n",
@@ -505,7 +512,7 @@ int main (int argc, char **argv)
 
 	for (i = -3; get_rgb && i < GMT_n_colors; i++) {
 		GMT_get_rgb_lookup (i, 0.0, rgb);
-		printf ("\t<Style id=\"GMT%ld\">\n", i);
+		printf ("\t<Style id=\"GMT-%ld-%ld\">\n", pid, i+4);
 		/* Set icon style (applies to symbols only */
 		printf ("\t\t<IconStyle>\n\t\t\t<scale>%g</scale>\n\t\t\t<color>%2.2x%2.2x%2.2x%2.2x</color>\n\t\t\t<Icon>\n\t\t\t\t<href>%s</href>\n\t\t\t</Icon>\n\t\t</IconStyle>\n",
 			scale, (unsigned int)itransp[POINT], (unsigned int)rgb[2], (unsigned int)rgb[1], (unsigned int)rgb[0], icon);
@@ -606,7 +613,7 @@ int main (int argc, char **argv)
 					printf ("\t\t</TimeSpan>\n");
 				}
 				else if (fmode == EVENT) printf ("\t\t<TimeStamp>\n\t\t\t<when>%s</when>\n\t\t</TimeStamp>\n", C[t1_col]);
-				printf ("\t\t<styleUrl>#GMT%ld</styleUrl>\n", index);
+				printf ("\t\t<styleUrl>#GMT-%ld-%ld</styleUrl>\n", pid, index+4);
 				printf ("\t\t<%s>\n", feature[fmode]);
 				print_altmode ((int)extrude, FALSE, (int)altmode);
 				printf ("\t\t\t<coordinates>");
@@ -663,7 +670,7 @@ int main (int argc, char **argv)
 						else
 							printf ("\t\t<name>%s %ld</name>\n", name[fmode], set_nr);
 						if (GMT_parse_segment_item (line->segment[i]->header, "-D", description)) printf ("\t\t<description>%s</description>\n", description);
-						printf ("\t\t<styleUrl>#GMT%ld</styleUrl>\n", index);
+						printf ("\t\t<styleUrl>#GMT-%ld-%ld</styleUrl>\n", pid, index+4);
 						printf ("\t\t<%s>\n", feature[fmode]);
 						print_altmode ((int)extrude, (int)fmode, (int)altmode);
 						if (fmode == POLYGON) {
@@ -720,7 +727,7 @@ int main (int argc, char **argv)
 							ascii_output_one (line->segment[i]->coord[t1_col][j], t1_col);
 							printf ("</when>\n\t\t\t</TimeStamp>\n");
 						}
-						printf ("\t\t\t<styleUrl>#GMT%ld</styleUrl>\n", index);
+						printf ("\t\t\t<styleUrl>#GMT-%ld-%ld</styleUrl>\n", pid, index+4);
 						printf ("\t\t\t<%s>\n\t", feature[fmode]);
 						print_altmode ((int)extrude, FALSE, (int)altmode);
 						printf ("\t\t\t\t<coordinates>");
