@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: pscoast.c 9975 2013-01-10 20:16:44Z pwessel $
+ *	$Id: pscoast.c 10185 2014-01-23 20:58:25Z pwessel $
  *
- *	Copyright (c) 1991-2013 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2014 by P. Wessel and W. H. F. Smith
  *	See LICENSE.TXT file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -129,7 +129,7 @@ int main (int argc, char **argv)
 	int level_to_be_painted = 0, direction, start_direction, stop_direction, last_pen_level;
 	int n_blevels = 0, n_rlevels = 0, bin_trouble;
 
-	GMT_LONG n;
+	GMT_LONG n, river_use[GMT_N_RLEVELS], border_use[GMT_N_BLEVELS];
 	
 	GMT_LONG	error = FALSE, shift = FALSE, need_coast_base, recursive;
 	GMT_LONG	greenwich = FALSE, possibly_donut_hell = FALSE, fill_in_use = FALSE;
@@ -529,29 +529,27 @@ int main (int argc, char **argv)
 		exit (EXIT_FAILURE);
 	}
 		
-	if (Ctrl->I.active) {
+	if (Ctrl->I.active) {	/* Generate array of desired river features in sorted order */
+		memset ((void *)river_use, 0, GMT_N_RLEVELS * sizeof (GMT_LONG));
 		for (k = n_rlevels = 0; k < GMT_N_RLEVELS; k++) {
 			if (!Ctrl->I.use[k]) continue;
 			if (Ctrl->I.pen[k].width < 0.0) {
 				fprintf (stderr, "%s: GMT SYNTAX ERROR -I option:  Pen thickness cannot be negative\n", GMT_program);
 				error++;
 			}
-			Ctrl->I.use[n_rlevels] = k;
-			Ctrl->I.pen[n_rlevels] = Ctrl->I.pen[k];
-			n_rlevels++;
+			river_use[n_rlevels++] = k;	/* Since goes from 0-10 */
 		}
 	}
 
-	if (Ctrl->N.active) {
+	if (Ctrl->N.active) {	/* Generate array of desired border features in sorted order */
+		memset ((void *)border_use, 0, GMT_N_BLEVELS * sizeof (GMT_LONG));
 		for (k = n_blevels = 0; k < GMT_N_BLEVELS; k++) {
 			if (!Ctrl->N.use[k]) continue;
 			if (Ctrl->N.pen[k].width < 0.0) {
 				fprintf (stderr, "%s: GMT SYNTAX ERROR -N option:  Pen thickness cannot be negative\n", GMT_program);
 				error++;
 			}
-			Ctrl->N.use[n_blevels] = k + 1;
-			Ctrl->N.pen[n_blevels] = Ctrl->N.pen[k];
-			n_blevels++;
+			border_use[n_blevels++] = k + 1;	/* Add one so we get range 1-3 */
 		}
 	}
 
@@ -858,14 +856,19 @@ int main (int argc, char **argv)
 
 	if (Ctrl->I.active) {	/* Read rivers file and plot as lines */
 
-		if (gmtdefs.verbose) fprintf (stderr, "%s: Adding Rivers...", GMT_program);
+		if (gmtdefs.verbose) {
+			fprintf (stderr, "%s: Adding Rivers features", GMT_program);
+			for (k = 0; k < n_rlevels; k++)
+				fprintf (stderr, " %ld", river_use[k]);
+		}
+			
 		if (!dumping) ps_comment ("Start of River segments");
 		last_k = -1;
 
 		for (ind = 0; ind < r.nb; ind++) {	/* Loop over necessary bins only */
 
 			bin = (int)r.bins[ind];
-			GMT_get_br_bin (ind, &r, Ctrl->I.use, n_rlevels);
+			GMT_get_br_bin (ind, &r, river_use, n_rlevels);
 
 			if (r.ns == 0) continue;
 
@@ -893,7 +896,7 @@ int main (int argc, char **argv)
 					GMT_n_plot = GMT_geo_to_xy_line (p[i].lon, p[i].lat, p[i].n);
 					if (!GMT_n_plot) continue;
 
-					k = (int)p[i].level;
+					k = (int)p[i].level;	/* k is 0-10 */
 					if (k != last_k) {
 						GMT_setpen (&Ctrl->I.pen[k]);
 						last_k = k;
@@ -915,7 +918,11 @@ int main (int argc, char **argv)
 
 	if (Ctrl->N.active) {	/* Read borders file and plot as lines */
 
-		if (gmtdefs.verbose) fprintf (stderr, "%s: Adding Borders...", GMT_program);
+		if (gmtdefs.verbose) {
+			fprintf (stderr, "%s: Adding Borders features", GMT_program);
+			for (k = 0; k < n_blevels; k++)
+				fprintf (stderr, " %ld", border_use[k]);
+		}
 		if (!dumping) ps_comment ("Start of Border segments");
 
 		/* Must resample borders because some points may be too far apart and look like 'jumps' */
@@ -927,7 +934,7 @@ int main (int argc, char **argv)
 		for (ind = 0; ind < b.nb; ind++) {	/* Loop over necessary bins only */
 
 			bin = (int)b.bins[ind];
-			GMT_get_br_bin (ind, &b, Ctrl->N.use, n_blevels);
+			GMT_get_br_bin (ind, &b, border_use, n_blevels);
 
 			if (b.ns == 0) continue;
 
@@ -956,7 +963,7 @@ int main (int argc, char **argv)
 					GMT_n_plot = GMT_geo_to_xy_line (p[i].lon, p[i].lat, p[i].n);
 					if (!GMT_n_plot) continue;
 
-					k = (int)(p[i].level - 1);
+					k = (int)(p[i].level - 1);	/* k is 0, 1, or 2 */
 					if (k != last_k) {
 						GMT_setpen (&Ctrl->N.pen[k]);
 						last_k = k;
