@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: pshistogram.c 10096 2013-10-13 02:16:09Z pwessel $
+ *	$Id: pshistogram.c 10194 2014-01-30 19:16:22Z pwessel $
  *
- *	Copyright (c) 1991-2013 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2014 by P. Wessel and W. H. F. Smith
  *	See LICENSE.TXT file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -550,8 +550,9 @@ GMT_LONG fill_boxes (struct PSHISTOGRAM_INFO *F, double *data, GMT_LONG n) {
 	/* First fill boxes with counts  */
 
 	for (i = 0; i < n; i++) {
-		ibox = (GMT_LONG)floor( ( (data[i] - F->west) / F->box_width) + add_half);
+		ibox = (GMT_LONG)irint (floor( ( (data[i] - F->west) / F->box_width) + add_half));
 		if (ibox < 0 || ibox >= F->n_boxes) continue;
+		//if (gmtdefs.verbose == 2) fprintf (stderr, "Value %g landed in box %ld\n", data[i], ibox);
 		F->boxh[ibox] ++;
 		F->n_counted++;
 	}
