@@ -1,7 +1,7 @@
 /*-----------------------------------------------------------------
- *	$Id: x2sys.c 9989 2013-03-04 19:14:06Z pwessel $
+ *	$Id: x2sys.c 10218 2014-02-27 21:38:00Z pwessel $
  *
- *      Copyright (c) 1999-2013 by P. Wessel
+ *      Copyright (c) 1999-2014 by P. Wessel
  *      See LICENSE.TXT file for copying and redistribution conditions.
  *
  *      This program is free software; you can redistribute it and/or modify
@@ -815,7 +815,7 @@ int x2sys_read_ncfile (char *fname, double ***data, struct X2SYS_INFO *s, struct
 	z = (double **) GMT_memory (VNULL, (size_t)s->n_out_columns, sizeof (double *), "x2sys_read_ncfile");
 	for (i = 0; i < s->n_out_columns; i++) z[i] = GMT_memory (VNULL, (size_t)GMT_io.ndim, sizeof (double), "x2sys_read_ncfile");
 
-	for (j = 0; j < GMT_io.ndim; j++) {
+	for (j = 0; j < (size_t)GMT_io.ndim; j++) {
 		if ((n_fields = GMT_input (fp, &n_expect, &in)) != s->n_out_columns) {
 			fprintf (stderr, "x2sys_read_ncfile: Error reading file %s at record %ld\n", fname, (GMT_LONG)j);
 	     		return (GMT_GRDIO_READ_FAILED);
